@@ -2,8 +2,9 @@
 // takes the file bayesallfile and reads it into the histogram structure
 // to use the calculate_hpd etc and also call the pretty printer functions
 //
-// (c) Peter Beerli 2007
+// (c) Peter Beerli 2007-2010
 //
+#include "definitions.h"
 #include "migration.h"
 #include "bayes.h"
 #include "tools.h"
@@ -12,8 +13,17 @@
 #include "pretty.h"
 
 extern int myID;
+#ifdef ZNZ
+void read_bayes_fromfile(znzFile mdimfile, world_fmt *world,option_fmt *options);
+#else
+void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options);
+#endif
 
+#ifdef ZNZ
+void read_from_bayesmdim_minimal_info(znzFile mdimfile, world_fmt *world,option_fmt *options, data_fmt *data)
+#else
 void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fmt *options, data_fmt *data)
+#endif
 {
   char *input;
   long nrep;
@@ -23,20 +33,36 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
   boolean recordedusem=TRUE;
 
   input = (char *) mycalloc(LINESIZE , sizeof(char));
+#ifdef ZNZ
+  while(done==FALSE && ZNZFGETS(input,LINESIZE,mdimfile) != EOF)
+#else
   while(done==FALSE && FGETS(input,LINESIZE,mdimfile) != EOF)
+#endif
     {
       if(input[0] == '#' && strstr(input,"begin"))
 	{
+#ifdef ZNZ
+	  ZNZFGETS(input,LINESIZE,mdimfile);
+#else
 	  FGETS(input,LINESIZE,mdimfile);
+#endif
 	  printf("%i>>>>>>> read from bayesallfile <<<<<<<<<<<<<<<<<<<<<<\n",myID);
 	  options->custm = (char *) myrealloc(options->custm, sizeof(char) * (strlen(input)+1));
 	  strcpy(options->custm,input+9);
 	  printf("%i> custom       = %s\n",myID, options->custm);
-	  FGETS (input, LINESIZE, mdimfile);
+#ifdef ZNZ
+	  ZNZFGETS(input,LINESIZE,mdimfile);
+#else
+	  FGETS(input,LINESIZE,mdimfile);
+#endif	  
 	  options->custm2 = (char *) myrealloc(options->custm2, sizeof(char) * (strlen(input)+1));
 	  strcpy(options->custm2,input+9);
 	  printf("%i> custom2      = %s\n",myID, options->custm2);
-	  FGETS (input, 1024, mdimfile);
+#ifdef ZNZ
+	  ZNZFGETS(input,LINESIZE,mdimfile);
+#else
+	  FGETS(input,LINESIZE,mdimfile);
+#endif
 	  sscanf (input+3, "%li %li %li %li %li %i", &world->loci, &world->numpop,
 		  &world->numpop2, &tmp, &options->replicatenum,&recordedusem);
 	  printf("%i> loci         = %li\n",myID, world->loci);
@@ -58,7 +84,11 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
         for (pop = 0; pop < world->numpop; pop++)
 	  {
             data->popnames[pop] = (char *) mycalloc (1, sizeof (char) * LINESIZE);
-	    FGETS (input, LINESIZE, mdimfile);
+#ifdef ZNZ
+	    ZNZFGETS(input,LINESIZE,mdimfile);
+#else
+	    FGETS(input,LINESIZE,mdimfile);
+#endif
 	    sscanf (input+3, "%s", data->popnames[pop]);
 	    printf("%i> population = %s\n",myID, data->popnames[pop]);
 	  }
@@ -75,8 +105,6 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
   myfree(input);
 }
 			    
-      
-void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options);
 
 long get_fullbinsum(MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, option_fmt *options, long locus)
 {
@@ -107,7 +135,11 @@ long get_fullbinsum(MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, op
 ///
 /// read bayesallfile from disk and creates all the needed parts to 
 /// recreate the output and pdf output
+#ifdef ZNZ
+void read_bayes_fromfile(znzFile mdimfile, world_fmt *world,option_fmt *options)
+#else
 void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
+#endif
 {
 
   long *n = NULL;
@@ -165,12 +197,22 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   //delta = (MYREAL *) mycalloc(nn-1, sizeof(MYREAL));
   n = (long *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(long));
   input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
+#ifdef ZNZ
+  unsigned long bytes = SUPERLINESIZE > ONEMEGABYTE ? SUPERLINESIZE : ONEMEGABYTE;
+  znzbuffer(mdimfile,bytes);
+  while(ZNZFGETS(input,SUPERLINESIZE,mdimfile) != EOF)
+#else
   while(FGETS(input,SUPERLINESIZE,mdimfile) != EOF)
+#endif
     {
       // grab the commentlines
       while(input[0]=='#' || input[0]=='S')
 	{
+#ifdef ZNZ
+	  ZNZFGETS(input,SUPERLINESIZE,mdimfile);
+#else
 	  FGETS(input,SUPERLINESIZE,mdimfile);
+#endif
 	}
       // read the bayesallfile
       
