@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: lrt.c 1608 2010-02-05 19:51:47Z beerli $
+$Id: lrt.c 1701 2010-06-13 21:00:45Z beerli $
  
 -------------------------------------------------------*/
 /* \file lrt.c 
@@ -269,6 +269,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
         aicfull = -2. * like1 + 2. * aicfullparamnum;
         FPRINTF(world->outfile,"          [the full model has AIC=%f, num(param)=%li]\n\n",aicfull,aicfullparamnum);
 
+	pdf_print_lrt_header(aicfull,aicfullparamnum, &world->page_width, &world->page_height);
       }
     print_lrt_box(world,param0, param1, zeros, elem, this_string1, like0, like1, df);
     myfree(lparam0);
@@ -316,6 +317,7 @@ void print_lrt_box(world_fmt *world, MYREAL *param0, MYREAL *param1, long zeros,
         box[i] = (char *) mycalloc(LRATIO_STRINGS,sizeof(char));
     newsize = parse_h0(&box,&size, this_string1,param0,param1,elem,world);
     print_box(world,box,newsize,like0,like1,testval, chiprob, chiprob2, aic, df, aicparamnum);
+    pdf_print_LRT_box(world,box,newsize,like0,like1,testval, chiprob, chiprob2, aic, df, aicparamnum, &world->page_height, & world->page_width);
     if(world->options->progress)
         print_line(stdout,'-',79,CONT);
     print_line(world->outfile,'-',79,CONT);
