@@ -134,7 +134,7 @@ void setup_parameter0_mpi (world_fmt * world, nr_fmt * nr, long repkind,
                            boolean multilocus);
 
 extern void setup_filehandle_db(FILE *file, world_fmt *world, option_fmt *options, data_fmt *data);
-extern long get_filehandle(FILE *file, world_fmt *world, option_fmt *options, data_fmt *data);
+extern long get_filehandle(void *file, world_fmt *world, option_fmt *options, data_fmt *data);
 extern void mpi_fprintf(FILE *file, const char *fmt, ...);
 #ifdef PARALIO
 extern void mpi_mdim_send(MPI_File *file, float *values, long size);
@@ -142,7 +142,7 @@ extern void mpi_mdim_send(MPI_File *file, float *values, long size);
 extern void mpi_mdim_send(float *values, long size);
 #endif
 //extern void mpi_mdim_send(float *values, long size);
-extern long get_filehandle2(FILE *file, world_fmt *world);
+extern long get_filehandle2(void *file, world_fmt *world);
 #ifdef SLOWNET
 extern void
 mpi_broadcast_results (world_fmt * world, long loci,
