@@ -476,7 +476,7 @@ void read_expected_values_fromfile(FILE *file, world_fmt *world)
 	  eventbins =  world->mighistloci[locus].eventbins;
 	  eventbinnum = world->mighistloci[locus].eventbinnum;
 	  eventbinsize = world->mighistloci[locus].eventbinsize;
-	  eventbinnum[pop] = i;
+	  eventbinnum[pop] = i+1;
 	  if(allocsize[spacer + pop] < eventbinnum[pop])
 	    {
 	      allocsize[spacer + pop] += SOME_ELEMENTS;
