@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1712 2010-08-20 04:17:16Z beerli $
+$Id: tools.c 1741 2010-10-23 20:27:28Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -105,6 +105,9 @@ void add_vector (MYREAL *result, MYREAL *v, long size);
 void init_files (world_fmt * world, data_fmt * data, option_fmt * options);
 void exit_files (world_fmt * world, data_fmt * data, option_fmt * options);
 void openfile (FILE ** fp, char *filename, char *mode, char *perm);
+#ifdef ZNZ
+void znzopenfile (znzFile * fp, char *filename, char *mode, int use_compressed);
+#endif
 long read_savesum (world_fmt * world, option_fmt * options, data_fmt * data);
 void write_savesum (world_fmt * world);
 
@@ -452,7 +455,7 @@ void start_node_collection(world_fmt *world)
 #ifdef MESS
   unique_id_global=0;
 #endif
-  world->node_collection_allocated = 2 * world->sumtips  + 2 * world->numpop * MIGRATION_LIMIT;
+  world->node_collection_allocated = 2 * HUNDRED  + 2 * world->numpop * MIGRATION_LIMIT;
   world->node_collection = (node **) calloc(world->node_collection_allocated,sizeof(node*));
 #ifdef MESS
   check_collection = (long *) calloc(world->node_collection_allocated, sizeof(long));
@@ -754,14 +757,28 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 			  {
 #ifdef MPI
 #ifndef PARALIO
-			    openfile (&world->bayesmdimfile, options->bayesmdimfilename, "w+",  NULL);
-#endif			  
+#ifdef ZNZ
+			    znzopenfile (&world->bayesmdimfile, options->bayesmdimfilename, "w", options->use_compressed);
 #else
 			    openfile (&world->bayesmdimfile, options->bayesmdimfilename, "w+",  NULL);
+#endif
+#endif			  
+#else
+#ifdef ZNZ
+			    znzopenfile (&world->bayesmdimfile, options->bayesmdimfilename, "w",  options->use_compressed);
+#else
+			    openfile (&world->bayesmdimfile, options->bayesmdimfilename, "w+",  NULL);
+#endif
 #endif
 			  }
 			else
-			  openfile(&world->bayesmdimfile, options->bayesmdimfilename,"r+",NULL);
+			  {
+#ifdef ZNZ
+			    znzopenfile (&world->bayesmdimfile, options->bayesmdimfilename, "r",  options->use_compressed);
+#else
+			    openfile(&world->bayesmdimfile, options->bayesmdimfilename,"r+",NULL);
+#endif
+			  }
 		      }
 #ifdef MPI
 		    if(options->has_bayesfile)
@@ -820,8 +837,12 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 	    if(options->has_bayesmdimfile)
 #ifdef PARALIO
 	      MPI_File_open(comm_world,options->bayesmdimfilename,MPI_MODE_CREATE,MPI_INFO_NULL, &world->mpi_bayesmdimfile);
+#else
+#ifdef ZNZ
+	    world->bayesmdimfile = (znzFile) filedb[j++].file;
 #else
 	      world->bayesmdimfile = filedb[j++].file;
+#endif
 #endif
 	  }
 #endif /*MPI*/
@@ -876,7 +897,11 @@ exit_files (world_fmt * world, data_fmt * data, option_fmt * options)
 	  if(options->has_bayesfile)
 	    FClose (world->bayesfile);
 	  if(options->has_bayesmdimfile)
+#ifdef ZNZ
+	    znzClose (world->bayesmdimfile);
+#else
 	    FClose (world->bayesmdimfile);
+#endif
 	}
     }
 }
@@ -1076,6 +1101,29 @@ void unread_word(FILE *infile, char *word)
 extern int errno;
 #endif
 
+#ifdef ZNZ
+/// opens a zip file for reading or writing
+void
+znzopenfile (znzFile * fp, char *filename, char *mode, int use_compressed)
+{
+  //int trials = 0;
+    znzFile of;
+    char *file;
+    char *p;
+    file = (char *) mycalloc(LINESIZE,sizeof(char));
+    if ((p = strpbrk (filename, CRLF)) != NULL)
+        *p = '\0';
+    remove_trailing_blanks(&filename);
+    strncpy (file, filename, LINESIZE - 1);
+    of = znzopen (file, mode,use_compressed);
+    if (znz_isnull(of))
+      error("Could not open zipped bayesallfile");
+    *fp = of;
+    myfree(file);
+}
+#endif
+
+
 /// opens a file for reading or writing
 void
 openfile (FILE ** fp, char *filename, char *mode, char *perm)
@@ -3308,6 +3356,49 @@ long print_to_buffer(char **buffer, long *maxbufsize, char *tempbuffer, long *po
   return (*pos);
 }
 
+/// sticks a text into the warning buffer that is printed at the end of the PDF and the end of the TEXT file
+void record_warnings(world_fmt * world, const char *fmt, ...)
+{
+  long mypos=0;
+  char *p = (char *) calloc(LINESIZE,sizeof(char));
+  va_list ap;
+  va_start(ap, fmt);
+  mypos = vsprintf(p, fmt, ap);
+  va_end(ap);
+  if((world->warningsize + mypos) < world->warningallocsize)
+      {
+	world->warningsize += sprintf(world->warning + world->warningsize, "%s\n",p);
+      }
+    else
+      {
+	world->warningallocsize = world->warningsize + 4 * mypos; // add some extra space
+	if(world->warning != NULL)
+	    world->warning = (char *) myrealloc (world->warning, world->warningallocsize * sizeof (char));
+	else
+	  world->warning = (char *) mycalloc (world->warningallocsize, sizeof (char));
+	world->warningsize += sprintf(world->warning + world->warningsize, "%s\n",p);
+      }
+  myfree(p);
+}
+
+void print_stored_warnings(world_fmt *world)
+{
+  if(world->warningsize>0)
+    {  
+      fprintf(world->outfile,"\nWARNINGS\n");
+      fprintf(world->outfile,"-------------------------------------------------------------------\n");
+      fprintf(world->outfile,"[You should most likely rerun your analysis after improving run parameters.]\n");
+      fprintf(world->outfile,"%s\n\n", world->warning);
+      if(world->options->progress)
+	{
+	  fprintf(stdout,"\nWARNINGS\n");
+	  fprintf(stdout,"-------------------------------------------------------------------\n");
+	  fprintf(stdout,"[You should most likely rerun your analysis after improving run parameters.]\n");
+	  fprintf(stdout,"%s\n\n", world->warning);
+	}
+    }
+}
+
 
 // calculates a rough approximation to log(val)
 // max error = 0.0007
